approval.signals API documentation

# approval.signals

Signals sent by the application.

View Source

    1"""Signals sent by the application."""
    2from django.dispatch.dispatcher import Signal
    3
    4# Sent just before an instance undergoes approval
    5pre_approval = Signal(["instance", "status"])
    6
    7# Sent just after an instance undergoes approval
    8post_approval = Signal(["instance", "status"])

pre_approval = <django.dispatch.dispatcher.Signal object>
post_approval = <django.dispatch.dispatcher.Signal object>